realtimekit_core_platform_interface library

Classes

ActiveTab
AudioDevice
AudioErrorUtils
BorderToken
ChatErrorUtils
ChatMessage
ErrorStringProvider<T extends RtkError>
FileMessage
GridPagesInfo
HostErrorUtils
ImageMessage
LinearColorSwatch
LivestreamView
LocalUserController
MeetingErrorUtils
MessageRateLimit
MethodChannelRtkClient
An implementation of RtkClientPlatform that uses method channels.
ParticipantFlags
ParticipantFlags class is used to store the participant flags.
PluginView
Poll
PollOption
PollsErrorUtils
Utility class for polls error handling
PollVote
RangedColorSwatch
RecordingErrorUtils
RtkChat
RtkChatController
RtkChatEventListener
RtkChatListenerChannel
RtkClientPlatform
The interface that implementations of rtk_core must implement.
RtkColorSwatch
RtkColorToken
RtkDataController
RtkDataEventListener
RtkDataListenerChannel
RtkDesignTokens
RtkGridPagesInfo
RtkGridPagesInfo class is used to store the grid pages information. It is used to paginate the participants in the grid view.
RtkJoinedMeetingParticipantApi
RtkListener
RtkListenerChannel<T extends RtkListener>
RtkLivestream
RtkLivestreamController
RtkLivestreamData
RtkLivestreamEventListener
RtkLivestreamListenerChannel
RtkLocalUserApi
RtkMeetingInfo
RtkMeetingParticipant
RtkMeetingParticipantApi
RtkMeetingRoomEventListener
RtkMeetingRoomEventListenerChannel
RtkMeta
RtkParticipantController
RtkParticipantEventsListenerChannel
RtkParticipants
RtkParticipants represents all the participants in the meeting (except the local user). It provides views to the current participants in the meeting as well as methods to modify them.
RtkParticipantsApi
RtkParticipantsEventListener
RtkPlugin
RtkPluginApi
RtkPlugins
RtkPluginsController
RtkPluginsEventListener
RtkPluginsListenerChannel
RtkPollController
RtkPollListenerChannel
RtkPolls
RtkPollsEventListener
RtkRecording
RtkRecordingController
RtkRecordingEventListener
RtkRecordingListenerChannel
RtkRemoteParticipant
RtkSelfEventListener
RtkSelfListenerChannel
RtkSelfParticipant
RtkStage
RtkStageController
RtkStageEventListener
RtkStageListenerChannel
RtkWaitingRoomListenerChannel
RtkWaitlistedParticipantApi
RtkWaitlistEventListener
ScreenshareView
SelfPermissions
SocketConnectionState
TextMessage
VideoDevice
VideoErrorUtils
VideoView

Extensions

ColorsUtils on Color

Functions

getColorFromStringHex(String hex) Color
returns a Color object by taking a String hex in the format of "#FFFFFF"
getErrorDataStringImpl(RtkError error) String

Typedefs

OnResult = void Function(RtkError? error)